import pytest

from portal import logger
from portal.database.models import Course, User
from portal.service.rest import RestService

log = logger.get_logger(__name__)


@pytest.fixture
def admin_user(app):
    return User.query.filter_by(username='admin').first()


@pytest.fixture
def student_user(app):
    return User.query.filter_by(username='student1').first()


@pytest.fixture
def course(app):
    return Course.query.filter_by(codename='testcourse1').first()


@pytest.fixture()
def perm():
    rest_service = RestService()
    return rest_service.permissions


def test_project_list_with_admin_permissions(perm, course, admin_user):
    service = perm(admin_user, course)
    assert service.check.permissions(['view_course_full'])


def test_project_list_with_non_admin_permissions(perm, student_user, course):
    service = perm(student_user, course)
    assert not service.check.permissions(['view_course_full'])


def test_project_list_with_non_admin_permissions_limited(perm, student_user, course):
    service = perm(student_user, course)
    assert service.check.permissions(['view_course_limited'])
